diff --git a/ML_prediction_2020.nc b/ML_prediction_2020.nc
index ce3b9bea6e7dab19771f22deef58314eb6f860ba..4ee741efc322484daabb3e10589bdcdf2d3b7f12 100644
--- a/ML_prediction_2020.nc
+++ b/ML_prediction_2020.nc
@@ -1,3 +1,3 @@
 version https://git-lfs.github.com/spec/v1
-oid sha256:3199d9ab2d260810eb4ac2defdbcc462a7d8ecba7a4a4aa009f8f9cfb8d2c359
-size 73902776
+oid sha256:de052442cd8ed26807c40ee545645609562687b3c9a894f219de8035bf77c2d0
+size 73909016
diff --git a/scoring/forecast-like-observations_2020_biweekly_terciled.nc b/scoring/forecast-like-observations_2020_biweekly_terciled.nc
index 77bc619c39cc4c1bb4a29d1a8fc3af7ea4eb0249..2c84985eb063d135caffdbeccfb96384cad47989 100644
--- a/scoring/forecast-like-observations_2020_biweekly_terciled.nc
+++ b/scoring/forecast-like-observations_2020_biweekly_terciled.nc
@@ -1,3 +1,3 @@
 version https://git-lfs.github.com/spec/v1
-oid sha256:59236c27571267bc3519ef169714302927b18ccaee1abcf5c1be3a0cf3f4b422
-size 73900831
+oid sha256:9f98b1c5e529875337637bc9e7f90fb897abff0051d893e5204fe708f653ed95
+size 73909736
diff --git a/scoring/scoring_script.py b/scoring/scoring_script.py
index 293af8a37aa864f1dbb18edc7e715cbb0d239ba6..4fd4534e6a2e2d1d9f7df774bb0f48c32ed01a4f 100644
--- a/scoring/scoring_script.py
+++ b/scoring/scoring_script.py
@@ -6,7 +6,7 @@ import pandas as pd
 import argparse
 from pathlib import Path
 
-def assert_predictions_2020(preds_test, exclude='weekofyear'):
+def assert_predictions_2020(preds_test, exclude='week'):
     """Check the variables, coordinates and dimensions of 2020 predictions."""
     from xarray.testing import assert_equal # doesnt care about attrs but checks coords
     if isinstance(exclude, str):
@@ -21,9 +21,9 @@ def assert_predictions_2020(preds_test, exclude='weekofyear'):
         assert 't2m' in preds_test.data_vars
     
     ## coords
-    # ignore weekofyear coord if not dim
-    if 'weekofyear' in exclude and 'weekofyear' in preds_test.coords and 'weekofyear' not in preds_test.dims:
-        preds_test = preds_test.drop('weekofyear')
+    # ignore week coord if not dim
+    if 'week' in exclude and 'week' in preds_test.coords and 'week' not in preds_test.dims:
+        preds_test = preds_test.drop('week')
     
     # forecast_time
     if 'forecast_time' not in exclude: